#
# spec file for package python-ryu
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-ryu
Version:        4.30
Release:        7.2
Summary:        Component-based Software-defined Networking Framework
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            http://osrg.github.io/ryu/
Source:         https://pypi.io/packages/source/r/ryu/ryu-%{version}.tar.gz
BuildRequires:  %{python_module pbr}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Routes
Requires:       python-WebOb >= 1.2
Requires:       python-eventlet >= 0.18.2
Requires:       python-msgpack >= 0.3.0
Requires:       python-netaddr
Requires:       python-oslo.config >= 1.15.0
Requires:       python-ovs >= 2.6.0
Requires:       python-ryu-common = %{version}
Requires:       python-six >= 1.4.0
Requires:       python-tinyrpc
BuildArch:      noarch

%python_subpackages

%description
Ryu is a component-based software defined networking framework. Ryu
provides software components with an API for creating network
management and control applications. Ryu supports various protocols
for managing network devices, such as OpenFlow, Netconf, OF-config,
etc. About OpenFlow, Ryu fully supports 1.0, 1.2, 1.3, 1.4, 1.5 and
Nicira Extensions.

%package -n python-ryu-common
Summary:        Configuration files for python-ryu, a SDN framework
Group:          Development/Languages/Python
Provides:       %{python_module ryu-common = %{version}}

%description -n python-ryu-common
Ryu is a component-based software defined networking framework. Ryu
provides software components with an API for creating network
management and control applications. Ryu supports various protocols
for managing network devices, such as OpenFlow, Netconf, OF-config,
etc. About OpenFlow, Ryu fully supports 1.0, 1.2, 1.3, 1.4, 1.5 and
Nicira Extensions.

%prep
%setup -q -n ryu-%{version}

%build
%python_build

%install
%python_install
mkdir -p %{buildroot}%{_sysconfdir}
mv %{buildroot}/usr/%{_sysconfdir}/ryu %{buildroot}%{_sysconfdir}/ryu
%python_clone -a %{buildroot}%{_bindir}/ryu
%python_clone -a %{buildroot}%{_bindir}/ryu-manager

%python_expand %fdupes %{buildroot}%{$python_sitelib}

%post
%{python_install_alternative ryu ryu-manager}

%postun
%python_uninstall_alternative ryu

%files %python_files
%defattr(-,root,root,-)
%doc AUTHORS ChangeLog README.rst
%license LICENSE
%{python_sitelib}/*
%python_alternative %{_bindir}/ryu
%python_alternative %{_bindir}/ryu-manager

%files -n python-ryu-common
%dir %{_sysconfdir}/ryu
%config(noreplace) %{_sysconfdir}/ryu/ryu.conf

%changelog
* Sat Dec  8 2018 jengelh@inai.de
- Redo summaries without em dashes. Trim filler wording from
  description.
* Fri Dec  7 2018 tbechtold@suse.com
- Convert to singlespec
* Wed Dec  5 2018 tbechtold@suse.com
- update to 4.30:
  * Ryu 4.30
  * Grammatical improvements to some of the documentation
  * Ryu 4.29
  * app/ofctl: fix possible deadlock when the datapath disconnects
  * Ryu 4.28
  * Fix convertion of ipv4 to string on i386 and arch
  * mrtlib: Define JSON representation types
  * test\_mrtlib: Test cases for ADD\_PATH
  * mrtlib: Support RFC8050
  * mrtlib: Missing subclass for SUBTYPE\_RIB\_\*\_MULTICAST
  * Ryu 4.27
  * Declare support of recent python3 versions
  * Test more python versions on travis CI
  * Bump oslo.config to 2.5.0
  * Fix UT when running in python 3.7 env
  * lib/ovs/bridge: Return multiple controllers
  * BGPSpeaker: Enable to specify remote port for neighbor
  * switch.tester: Fix name shadowing
  * gui\_topology: Avoid wildcard URL matching
  * Ryu 4.26
  * nx\_actions: Fix NXActionSetTunnel docstring
  * Fix pycodestyle W605 warnings
  * BGPSpeaker: Fix BGP state string conversion
  * pycodestyle: Ignore W504
  * BGPSpeaker: Advertise local routes to RR clients
  * pip: Blacklist eventlet 0.23.0
  * lldp: Remove remaining SystemCapabilities.subtype from tests
  * lldp: fixed SystemCapabilities TLV
  * Ryu 4.25
  * allow versions of eventlet > 0.21.0
* Wed Apr 25 2018 tbechtold@suse.com
- update to 4.24:
  * Ryu 4.24
  * ofproto: add Nicira extension ct\_clear action
  * ofproto: Encode data field on OFPErrorMsg
  * ofp\_handler: Close socket when HELLO failed
  * controller: Wait for switch to disconnect connection
  * controller: Option to close socket after sending Message
  * controller: Improve pylint result
  * test\_requirements: Avoid using pip as library
  * utils: Remove "parse\_requirements" function
  * Switch to msgpack in pip-requires
  * nicira\_ext: Support DEC\_NSH\_TTL action
  * nicira\_ext: Support Network Service Header match
  * doc: Fix unexpected indent in ofctl.api doc
  * Ryu 4.23
  * doc: Document for ryu.lib.ovs
  * lib/ovs: Fix a typo of "--may-exist" option
  * Ryu 4.22
  * bgp/application: Add note for BGPSpeaker API reference
  * BGPSpeaker: Move docstring from \_\_init\_\_ to class
  * BGPSpeaker: Enable to notify adj-RIB-in changed
  * ofctl: Enable to get all datapath objects
  * confroller/dpset: Add usage example of instantiation
  * test\_rpc: Adopt to msgpack-python>=0.50
* Mon Mar  5 2018 tbechtold@suse.com
- Fix Requires for python-Routes
* Mon Mar  5 2018 tbechtold@suse.com
- update to 4.21:
  * Ryu 4.21
  * \*: Apply autopep8
  * travis: Introduce autopep8 test
  * \*: Adopt to pycodestyle's checks
  * pycodestyle: Replace pep8
  * ofproto_v1_5_parser: oxm_ids with name str in OFPActionCopyField
  * ofproto_v1_5_parser: Missing trailing pads of OFPActionCopyField
  * ofproto_v1_5_parser: Fix length calculation of OFPOxmId
  * ovsdb: Fix small bug
  * packet_data_generator3: Generate OF13 Ext-230 bundle packets
  * packet_data_generator3: Support ovs-2.8
  * ofproto_v1_3: Add bundle extension
  * ofproto: Correct OFPBundle{Ctrl, Add}Msg docstrings
  * rest_vtep: Add some descriptions for troubleshooting
  * topology: Enable to detect migrations of hosts
  * Ryu 4.20
  * fix bug in the example of flow_stats_reply
  * app: added simple switch with openflow 1.5 support
  * ofproto_v1_5_parser: Change default of command_bucket_id
  * app: Fix simple_switch for multi switch env
  * doc: fix typo
  * test_icmpv6: Catch proper Exception
  * packet/icmp: Avoid TypeError when calculating length
  * \*: Reject Binary Represented IP Addresses
  * serivice/bgp: Fix ssh connection problem in Python 2.7
  * flags: Inject __class__ attribute to LooseVersion
  * library_ovsdb_manager: Descriptions for OVS configs
  * app/ofctl: Enable to send single BarrierRequest
  * packet/zebra: Support FRRouting version 3.0
  * of14: Implement OFPBundleCtrlMsg parser
  * rest_qos: Avoid None when deleting OVSDB addr
  * lib/ovs/vsctl: Function for validate OVSDB address
  * Ryu 4.19
  * BGPSpeaker: Enable to specify local listen addresses
  * bgp/application: Enhance arguments handling for BGPSpeaker
  * test_controller: Test cases for _split_addr()
  * controller: APIs to register switch address dynamically
  * controller: Support proactive connection
  * Ryu 4.18
  * zclient/zserver: Support FRRouting messages format
  * test_zebra: Enhance test cases
  * packet/zebra: Support MPLS Labels messages
  * packet/zebra: Support Interface Router Advertisement messages
  * packet/zebra: Support VRF related messages
  * packet/zebra: Support BFD Destination messages
  * packet/zebra: Support Neighbor Connected Address messages
  * test_zebra: Add pcap for API version 4 on FRR v2.0
  * packet/zebra: Support some FRRouting messages format
  * packet/zebra: Constants for supporting FRRouting format
  * packet/zebra: Support asymmetric structure of ZEBRA_\*_IMPORT_LOOKUP
  * packet/zebra: Parse messages based on Zebra API version
  * packet/zebra: Missing bw_cls_num in InterfaceLinkParams
  * packet/zebra: Constants for Link Parameters Status
  * packet/zebra: Constants for Interface Address Flags
  * packet/zebra: Return "ZebraMessage" for message from Zebra
  * packet/zebra: Fix unresolved reference for _serialize_nexthops
  * Only import pip if needed
  * Ryu 4.17
  * topology/switches: Fix delete port can't immediately remove link
  * BGPSpeaker/net_ctrl: Close activity for each session
  * packet/bmp: Correctly parse peer address with IPv4
  * rest_qos: Avoid discarding Queues info for each request
  * services/ovsdb: Listen on IPv6 Address
  * packet/icmpv6: Assert length in options are valid
  * packet/icmpv6: Fix parsing undefined nd_option fails
  * ofp_event: Timestamp when OpenFlow event was generated
  * Ryu 4.16
  * doc: Fix unexpected indent in ryu/lib/packet/bgp.py
  * doc: Deprecated option html_use_smartypants
  * ofproto: Avoid emitting illegal instruction sets
  * doc: Minor grammar changes in ryu_app_api
  * unit/ofproto: Adopt to rename of OFPErrorExperimenterMsg
  * ofproto: Handle OFPErrorExperimenterMsg
  * bgp_sample_conf: absolute_import to suppress warnings
  * service/ovsdb: get socket from RemoteOvsdb
- Drop only-import-pip-when-needed.patch (applied upstream)
* Fri Sep 22 2017 dmueller@suse.com
- add only-import-pip-when-needed.patch
- remove python-pip requirement again
* Wed Aug 30 2017 snica@suse.com
- add missing python-pip requirement
* Tue Aug  8 2017 tbechtold@suse.com
- update to 4.15:
  * Revert "tests: Separate test files from Ryu module"
  * tests: Separate test files from Ryu module
  * service/ovsdb: Use dict.items() instead of six.iteritems()
  * doc/ovsdb\_manager: Update Sample Code
  * service/ovsdb: Use Python 2/3 compatible code
  * service/ovsdb: Avoid to use dict as default argument
  * service/ovsdb: Add properties to EventNewOVSDBConnection
  * test\_vsctl: Strip unexpected double quote
  * pip: OpenStack updated requirements of eventlet again
  * manager: Introduce user flags option
  * CONTRIBUTING: Update info of Python ver/lib and links
  * CONTRIBUTING: Update procedure for running tests
  * CONTRIBUTING: Update procedure for submitting patches
  * README: Dependencies for installing optional requirements
  * service/ovsdb: Default of controller\_info in set\_controller
* Tue Jun 20 2017 johannes.grassler@suse.com
- Update to 4.14
  * doc: fix error in ovsdb_manager.rst code
  * fix dhcp6.py bug using python3
  * pip: OpenStack avoids newer eventlet
  * ofctl: Add some tests for ofp_instruction_from_str
  * ofctl: Add ovs-ofctl style action string parser
  * nicira_ext: Define some CT constants
  * BGPSpeaker/SSH: Support to show L2VPN Flow Spec routes
  * BGPSpeaker: Support IPv6 Flow Spec update messages
  * BGPSpeaker/info_base: Add tables for L2VPN Flow Spec
  * utils/test_bgp: Add unit tests for L2VPN Flow Spec
  * test_table_manager: Add unit tests for L2VPN Flow Spec
  * test_bgpspeaker: Add unit tests for L2VPN Flow Spec
  * packet/bgp: Support L2VPN Flow Spec
  * packet/bgp: Properly calculate length for FlowSpec
  * test_bgp: Add test cases for L2VPN Flow Spec
  * BGPSpeaker/SSH: Support to show IPv6 Flow Spec routes
  * BGPSpeaker: Support IPv6 Flow Spec update messages
  * BGPSpeaker/info_base: Add tables for IPv6 Flow Spec
  * utils/test_bgp: Add unit tests for IPv6 Flow Spec
  * test_table_manager: Add unit tests for IPv6 Flow Spec
  * test_bgpspeaker: Add unit tests for IPv6 Flow Spec
  * packet/bgp: Support IPv6 Flow Spec
  * test_bgp: Add test cases for IPv6 Flow Spec
  * ofproto: Allow CIDR notation for ipv[46]_{src, dst}
  * utils.import_module: Prefer filepath than Python module
  * library_packet_ref: Separate ref into each protocol
  * lib/packet: Use literal block for diagram in pydoc
  * packet/bgp: Omit description of default value
  * packet/lldp: Add description for each class
  * packet/arp: Update description for arguments
  * BGPSpeaker/info_base/base: Unify documentation format
  * BGPSpeaker: Unify documentation format
  * BGPSpeaker: Improve EVPN Redundancy Mode validation
  * bgp: Enable to configure default local preference
  * packet/zebra: Support IP_ROUTE message from Zebra
  * lib/hub: Workaround for issue of eventlet
* Fri Dec 16 2016 tbechtold@suse.com
- update to 4.9:
  * scenario test: Fix the wrong retry check in command execution
  * Enable to run a scenario test with a specific python version
  * rest_firewall: Compare reserved port in str representation
  * test_vsctl: Use osrg/ryu-book image as Mininet container
  * test_vsctl: Wait for loading OVS kernel module
  * integrated/bgp: Use Ubuntu:16.04 for base image
  * docker_base: Update base image to Ubuntu:16.04
  * BGPSpeaker: Confirm SSH feature to be optional
  * docker_base: Add missing requirements for test-requires
  * README: Use pip to resolve dependencies
  * pip: Separate test-requires
  * RPC: Specify encoding to msgpack.Packer/Unpacker
  * test_rpc: Use numbers.Integral instead of long type
  * wsgi: Avoid using inspect.getargspec
  * wsgi: Reduce pylint warnings
  * wsgi: Use six.text_type instead of unicode
  * contrib: Revert module path to ryu.contrib
  * protocols/bgp/base: Add missing __next__ method
  * BGPSpeaker: Support to advertise EVPN IP Prefix route
  * packet/bgp: Support for IP Prefix Route encoding
  * packet/bgp: Fix the EvpnNLRI to use the ryu.lib.packet.vxlan
  * packet/bgp: Fix the EvpnNLRI to use the ryu.lib.packet.mpls
  * packet/bgp: Fix the EvpnNLRI to use the ryu.lib.ip
  * BGPSpeaker: Enable to set capability for IPv6
  * test_bgp: Add test cases for IPv6 and VPNv6 routes
  * test_bgp: Enable to check parsed BGP message
  * packet/bgp: Refactor MP_REACH_NLRI and MP_UNREACH_NLRI
  * lib/ip: Add method to convert IPv4/IPv6 to int
  * test_bgp: Uncomment out test case for UPDATE
  * packet/bgp: Enable Extended Length flags if specified
  * pip: Move tinyrpc to pip-requires
* Tue Nov 15 2016 dmueller@suse.com
- update to 4.5:
  * Ensure that send() and send_msg() in controller return status to calling applications
  * Clean up stale Datapath objects in the ofctl_service application
  * packet lib: Add packet library of GRE
  * ofproto/nx_actions: Update argument of NXActionCT
  * ofproto/nx_actions: Revert API of NXAction
  * manager: Except KeyboardInterrupt to suppress traceback
  * stplib: Handle the port state not changed events
  * stplib: Adopt to Python3
  * rest_qos: Fix to handle the case without QoS action
  * packet: support relayed DHCP packet
  * Fix: LLDP.OrganizationallySpecific not ignoring info field
  * test_parser: Add test data for some NXAction
  * ofproto/nx_actions: Support some NXAction
  * ofproto/nx_actions: Add comment for Ryu documents
  * test_parser: Add test data for missing NXAction
  * ofproto/nx_actions: Support missing NXAction
  * ofproto/nx_actions: Update arguments to be compatible with ovs-ofctl
  * test_parser: Add test data for NXAction used only in OpenFlow1.0
  * ofproto/nx_actions: Add NXAction used only in OpenFlow1.0
  * test_packet: Avoid to use array.array as input binary
  * packet: Fix minimum ethernet frame length
  * test_peer: Unit test for peer.py of BGPSpeaker
  * BGPSpeaker: Support Four-Octet AS number
  * packet/bgp: Support Four-Octet AGGREGATOR Path Attribute
  * BGPSpeaker: Fix capability check when MP-BGP not supported
  * fix of13 VLAN_PCP test case
  * Ryu 4.4
  * topology: ignore cfm packets on packet in
  * topology: pep8 fixes
  * ofproto: Fix example of OFPSetAsync message
  * Update the readthedoc URL
  * lib/ofctl_utils: Log the datapath sent to
  * Avoid parallel executions of AppManager.close()
  * python3: Use six.add_metaclass for metaclass
  * python3: Use six.string_types instead of basestring
  * python3: Improve Table class in services.protocols.bgp.info_base.base
  * python 3: Replace deprecated logging.warn with logging.warning
  * Python3: Explicit string type encoding
  * BGPSpeaker: Remove unused utility modules
  * BGPSpeaker: Fix unresolved references in Python3
  * BGPSpeaker: Support Per-Peer AS
  * packet_data_generator3/gen: Add some NXAction packets
  * ofproto/nicira_ext: Move the variable and method for Nicira Extension
  * tests/test_parser_v10: Update test parameter
  * ofproto/nx_actions: Update arguments to be compatible with ovs-ofctl
  * ofproto/ofproto_v1_0: Delete some NX actions
  * ofproto/nx_actions: Porting the NX Action definition of ofproto_v1_0_parser
  * ofproto/nx_actions: Update serialize and parse
  * Extend OVSDB api
  * Fix RuntimeError of lldp_packet_in_handler
  * Ryu 4.3
  * nx_match: add tun_ipv6_{src,dst}
  * packet_data_generator3: Clear xid into zero
  * ofproto: Implement OFPFlowMod parser
  * doc: Add PCAP file library reference
  * test_pcaplib: Add unit tests for pcaplib
  * pcaplib: Reduce Pylint warnings
  * test_bgp: Enable to test parser with pcap file
  * packet/bgp: Reduce Pylint warnings
  * bgp: fix typos
  * test-requires: Update to use the latest Pylint
* Tue Nov 15 2016 dmueller@suse.com
- update to 4.8.1:
  * pip: Move tinyrpc to pip-requires
  * Ryu 4.8
  * contrib/tinyrpc: Remove embedded tinyrpc, use upstream
  * contrib/ncclient: Remove embedded ncclient, use upstream
  * ut/ovs: Add UT using Docker for ryu.lib.ovs
  * BGPSpeaker: Support to advertise PMSI Tunnel Attribute
  * packet/bgp: Add PMSI Tunnel Attribute
  * packet/vxlan: Add method to convert the format of vni
  * packet/mpls: Add method to convert the format of label
  * lib/ip: Add method to convert the format of Ipv4 or Ipv6
  * Enable to run a scnario test for ryu bgp on travis
  * Add scripts which install a dependency package
  * Add bgp scenario tests
  * Add bgp scenario tests tool
  * bgp/application: Re-implement base BGP application
  * flags: Add CLI options for BGP application
  * BGPSpeaker: Enable to specify settings for SSH CLI
  * bgp/operator/ssh: Enable to quit gracefully
  * bgp/operator/ssh: Reduce pylint warnings
  * BGPSpeaker: Use dictConfig in the standard library
  * utils: Backward compatibility for 'imp.load_source'
  * Log OFPErrorMsg.data as ascii when type is OFPET_HELLO_FAILED
  * ovs/vsctl: Fix API for parsing column/key/value set
  * ovs/vsctl: Add missing Controller commands in OVS v2.6.0
  * ovs/vsctl: Add missing Port commands in OVS v2.6.0
  * ovs/vsctl: Add missing Interface commands in OVS v2.6.0
  * ovs/vsctl: Add missing Bridge commands in OVS v2.6.0
  * ovs/vsctl: Sort out commands order
  * ovs/bridge: Add APIs for missing Database commands
  * ovs: Add API corresponding to ovs-vsctl remove command
  * ovs: Add API corresponding to ovs-vsctl add command
  * ovs: Add API corresponding to ovs-vsctl list command
  * ovs: Add API corresponding to ovs-vsctl add-bond command
  * ovs/vsctl: Update command list with OVS v2.6.0
  * ovs/vsctl: Avoid applying next() to non-iterator object
  * ovs/vsctl: Add missing required argument for find_vlan_bridge
  * ovs: Reduce pylint warnings
  * ovs: Revert ovs module path
  * ovs/vsctl: Fix VSCtlCommand to inherit StringifyMixin
  * ovs/vswitch_idl: Update OVSDB schema with v7.14.0
  * ovs/vsctl: Change log level of redundant messages
  * rest_router: Fix conversion of Packet Library to dict
  * dpset: Fix iteration error when disconnecting switches
  * test_parser: Add an truncate packet test
  * test_parser: Enable tests for truncated packets
  * ofproto_v1_3_parser: Raise OFPTruncatedMessage exception on truncated messages
  * ofproto/nicira_ext: Add missing NXMs in OVS v2.6.0
  * ryu/lib/ofctl_v1_3: port name decoding fix
  * BGPSpeaker: Enhance APIs for operator.show
  * Ryu 4.7
  * BGPSpeaker: Fix to enable to notify peer down
  * use old cryptography version
  * packet: Avoid parsing an empty buffer
  * pip-requires: Add ovs>=2.6.0
  * doc: Add API reference for REST EVPN switch
  * app: Add sample application for REST EVPN switch
  * app: Integrate aplication of Ryu-book
  * ovs/bridge: Enable to request tunnel port number
  * ovs/bridge: Add utility method to create VXLAN port
  * ovs/bridge: Make local_ip to optional field for tunnel
* Thu May 19 2016 tbechtold@suse.com
- update to 4.2.1:
  * packet/bgp: Add missing __hash__ function
  * controller: Add backward compatibility for 6633 port
  * Update default OpenFlow port to 6653
  * BGP: Make RouteFamily class hashable
  * doc: Remove warnings when building doc pages
  * doc: Move Ryu App API doc into each source code
  * network: Fix unresolved reference
  * doc: Add description for EventOFPPortStateChange
  * controller: Implement EventOFPPortStateChange
  * doc/app/ofctl_rest: Remove unused match field
  * doc/source/conf: Set the False to SmartyPants
  * doc/app/ofctl_rest: Add a description for openflow1.5
  * doc/app/ofctl_rest: Update the optional parameter of the message
  * doc/app/ofctl_rest: Add pbb_uca to match field
  * doc/app/ofctl_rest: Update the description method of Example
  * doc/app/ofctl_rest: Add Openflow version
  * Bump version requirement for oslo.config, given usage of min parameter to IntOpt
  * tox: Integrate Coveralls.io
  * tox: Add Python 3.5
  * test_ofctl: Add test cases for new Actions of of15
  * test_ofctl_rest: Add unit tests for ofctl_rest
  * test_ofctl: Add test cases for OpenFlow 1.5
  * ofctl_rest: Support OpenFlow 1.5
  * lib/ofctl: Support OpenFlow 1.5
  * ofproto_v1_5_parser: Fix serialized length of OFPActionCopyField
  * ofctl_v1_4: Port some improvements from ofctl_v1_3
  * ofctl_v1_4: Rename to get_queue_desc for uniformity
  * ofctl_v1_4: Support request parameters
  * ofctl_utils: Enhance user value conversion
  * REST Apps: Adopt to Python 3
  * topology: Adopt to Python 3
  * ofctl_rest: Enable to omit port_no and queue_id
  * ofctl_rest: Adopt decorator to simplify
  * test_ofctl: Test cases for omitting port_no in get_queue_config
  * lib/ofctl_v1_[23]: Unify the arguments order
  * ofctl_utils: Confirm binary type data in send_experimenter
  * test_import_module: Update test cases
  * utils: fix for temporarily storing the value of sys.path
  * Ryu 4.2
  * Enable filtering the OVSDB schema tables/columns
  * tox: Upgrade PyPy version to 2.6
  * Eventlet throws a subclass of IOError when an SSL read timeout occurs.
    Ensure that the read loop continues in this case
  * Added support for the tcp flags nicira extension
  * Removes unnecessary Windows requirements
- Adjust Requires
* Fri Mar  4 2016 tbechtold@suse.com
- Initial packaging (version 4.0)
